@@ -221,7 +221,7 @@ class property:
 		may_change=True,  # type: bool
 		identifies=False,  # type: bool
 		unique=False,  # type: bool
-		default=None,  # type: Any
+		default=None,  # type: Optional[Union[str, Union[bool,int], Tuple[str, List[str]], Tuple[Callable, List[str], Any)]]
 		prevent_umc_default_popup=False,  # type: bool
 		dontsearch=False,  # type: bool
 		show_in_lists=False,  # type: bool
@@ -305,7 +305,7 @@ class property:
 		return pattern_replace(copy.copy(res), object)
 
 	def default(self, object):
-		base_default = copy.copy(self.base_default)
+		base_default = copy.copy(self.base_default)  # type: Optional[Union[str, Union[bool,int], Tuple[str, List[str]], Tuple[Callable, List[str], Any)]]
 		if not object.set_defaults:
 			return [] if self.multivalue else ''
 
