@@ -116,18 +116,22 @@ class object(univention.admin.handlers.simpleLdap):
 		univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
 
 	def _ldap_addlist(self):
-		return [
+		al = super(object, self)._ldap_addlist()
+		return al + [
 			(self.superordinate.mapping.mapName('zone'), self.superordinate.mapping.mapValue('zone', self.superordinate['zone'])),
 		]
 
 	def _ldap_post_create(self):
+		super(object, self)._ldap_post_create()
 		self._updateZone()
 
 	def _ldap_post_modify(self):
+		super(object, self)._ldap_post_modify()
 		if self.hasChanged(self.descriptions.keys()):
 			self._updateZone()
 
 	def _ldap_post_remove(self):
+		super(object, self)._ldap_post_remove()
 		self._updateZone()
 
 	@classmethod
