@@ -33,25 +33,28 @@
 
 from __future__ import absolute_import
 
-import hashlib
+import base64
+import calendar
 import codecs
+import copy
+import hashlib
 import os
 import re
-import copy
 import time
-import calendar
-import base64
+from datetime import datetime
 
-from M2Crypto import X509
 import ldap
+import pytz
 import six
 from ldap.filter import filter_format
+import tzlocal
+from M2Crypto import X509
 
 import univention.admin
-from univention.admin.layout import Tab, Group
 import univention.admin.allocators
 import univention.admin.filter
 import univention.admin.handlers
+import univention.admin.handlers.settings.prohibited_username
 import univention.admin.localization
 import univention.admin.mapping
 import univention.admin.modules
@@ -60,12 +63,28 @@ import univention.admin.samba
 import univention.admin.syntax
 import univention.admin.uexceptions
 import univention.admin.uldap
-import univention.admin.handlers.settings.prohibited_username
-from univention.admin import configRegistry
-from univention.lib.s4 import rids_for_well_known_security_identifiers
-
 import univention.debug as ud
 import univention.password
+from univention.admin import configRegistry
+from univention.admin.layout import Group, Tab
+from univention.lib.s4 import rids_for_well_known_security_identifiers
+
+try:
+	from univention.admin.syntax import ActivationDateTimeTimezone
+except ImportError:
+	# workaround for errors during errata-updates. should be removable with UCS 5.0-1
+	class ActivationDateTimeTimezone(univention.admin.syntax.complex):
+		"""
+		Syntax for YYYY-mm-dd HH:MM TZNAME
+		"""
+		delimiter = ' '
+		subsyntaxes = [('Date', univention.admin.syntax.iso8601Date), ('Time', univention.admin.syntax.TimeString), ('Timezone', univention.admin.syntax.string)]
+		subsyntax_names = ('date', 'time', 'timezone')
+		subsyntax_names = ('activation-date', 'activation-time', 'activation-timezone')
+		size = ('TwoThirds', 'TwoThirds', 'TwoThirds')
+		all_required = False
+		min_elements = 0
+	univention.admin.syntax.ActivationDateTimeTimezone = ActivationDateTimeTimezone
 
 if not six.PY2:
 	long = int
@@ -229,6 +248,13 @@ property_descriptions = {
 		default='0',
 		size='Two',
 	),
+	'accountActivationDate': univention.admin.property(
+		short_description=_('Activate user account starting from'),
+		long_description=_('This disables the account until the specified time.'),
+		syntax=univention.admin.syntax.ActivationDateTimeTimezone,
+		dontsearch=True,
+		default=[[None, None, tzlocal.get_localzone().zone], []],
+	),
 	'locked': univention.admin.property(  # This property only serves two purposes: 1) filtering 2) artificial simulation of lockout
 		short_description=_('Locked state of account'),
 		long_description=_('This indicates if the account is locked out due to too many authentication failures.'),
@@ -749,6 +775,9 @@ layout = [
 			['unlock'],
 			['unlockTime'],
 		]),
+		Group(_('Activation'), layout=[
+			['accountActivationDate'],
+		]),
 		Group(_('Windows'), layout=[
 			['homedrive', 'sambahome'],
 			['scriptpath', 'profilepath'],
@@ -1189,6 +1218,33 @@ def unmapWindowsFiletime(old, encoding=()):  # type: (List[bytes]) -> str
 	return u''
 
 
+def datetime_from_local_datetimetimezone_tuple(local_datetimetimezone_tuple):  # type: (List[str]) -> datetime.datetime
+	d, t, tz = local_datetimetimezone_tuple
+	# dttz_str = module.property_descriptions[key].syntax.tostring(local_datetimetimezone_tuple)
+	naive_dt = datetime.strptime("%s %s" % (d, t), "%Y-%m-%d %H:%M")
+	return pytz.timezone(tz).localize(naive_dt)
+
+
+def mapDateTimeTimezoneTupleToUTCDateTimeString(local_datetimetimezone_tuple, encoding=()):  # type: (List[str]) -> List[bytes]
+	if local_datetimetimezone_tuple and all(local_datetimetimezone_tuple):
+		dt = datetime_from_local_datetimetimezone_tuple(local_datetimetimezone_tuple)
+		return [dt.astimezone(pytz.utc).strftime("%Y%m%d%H%M%SZ").encode(*encoding)]
+	return []
+
+
+def unmapUTCDateTimeToLocaltime(attribute_value, encoding=()):  # type: (List[bytes]) -> List[str]
+	if attribute_value and attribute_value[0]:
+		generalizedtime = attribute_value[0].decode(*encoding)
+		try:
+			utc_datetime = datetime.strptime(generalizedtime, "%Y%m%d%H%M%SZ")
+		except ValueError:
+			ud.debug(ud.ADMIN, ud.ERROR, 'Value of krb5ValidStart is not in generalizedTime format: %s' % (generalizedtime,))
+			raise
+		local_datetimetimezone_tuple = datetime.strftime(utc_datetime, "%Y-%m-%d %H:%M UTC").split()
+		return local_datetimetimezone_tuple
+	return []
+
+
 mapping = univention.admin.mapping.mapping()
 mapping.register('username', 'uid', None, univention.admin.mapping.ListToString)
 mapping.register('uidNumber', 'uidNumber', None, univention.admin.mapping.ListToString)
@@ -1242,6 +1298,7 @@ mapping.register('userCertificate', 'userCertificate;binary', univention.admin.m
 mapping.register('jpegPhoto', 'jpegPhoto', univention.admin.mapping.mapBase64, univention.admin.mapping.unmapBase64)
 mapping.register('umcProperty', 'univentionUMCProperty', mapKeyAndValue, unmapKeyAndValue)
 mapping.register('lockedTime', 'sambaBadPasswordTime', mapWindowsFiletime, unmapWindowsFiletime)
+mapping.register('accountActivationDate', 'krb5ValidStart', mapDateTimeTimezoneTupleToUTCDateTimeString, unmapUTCDateTimeToLocaltime, encoding='ASCII')
 
 mapping.registerUnmapping('sambaRID', unmapSambaRid)
 mapping.registerUnmapping('passwordexpiry', unmapPasswordExpiry)
@@ -1635,6 +1692,10 @@ class object(univention.admin.handlers.simpleLdap):
 
 		if self['unlock'] == '1':
 			self['locked'] = u'0'
+		if self.hasChanged('disabled') and self['disabled'] == '0' and not self.hasChanged('accountActivationDate'):
+			self['accountActivationDate'] = self.descriptions['accountActivationDate'].default(self)
+		if self['accountActivationDate'] and all(self['accountActivationDate']) and datetime.now(tz=pytz.utc) < datetime_from_local_datetimetimezone_tuple(self['accountActivationDate']):
+			self['disabled'] = '1'
 		if self['disabled'] == '1':
 			self['locked'] = u'0'  # Samba/AD behavior
 
